$(document).ready(function()
{
	var key = "d40e4f1b7fe64172aa5fefce8941b86b";
		
	$.ajax({
		url: 'http://openexchangerates.org/api/latest.json?app_id=' + key,
		success: function(data)
		{
			$("#loading-overlay").fadeOut();
			$("#loading-text").fadeOut();
			setup(data.rates);
		}
	});

	var setup = function(rates)
	{
		// Conversion
		{
			var fieldInitials = [ "EUR", "USD" ];
			var fields = [];
			var fieldsTable = $("#fields");
			var fieldsElement = $("<tr/>");
			fieldsTable.append(fieldsElement);
			
			// Generate inputs
			fieldInitials.forEach(function(e)
			{
				var val = $('<input type="number" min="0" step="any"/>');
				val.attr("max", Number.MAX_VALUE);
				var type = $('<select />');
			
				for (var key in rates)
				{
					var option = $("<option />");
					option.text(key);
					option.attr("value", rates[key]);
				
					if (key == e)
						option.attr("selected", "");
					
					type.append(option);
				}
		
				fields.push({
					val: val,
					type: type
				});
			});
	
			var update = function(current, basedOn)
			{
				// a / c1 = b / c2
				// a = (b / c2) * c1
				var b = parseFloat(basedOn.val.val());
				var c2 = parseFloat(basedOn.type.val());
			
				var c1 = parseFloat(current.type.val());
				var a = (b / c2) * c1;
				
				// On the matter of thousands separators:
				// It's not something the web-application should be enforcing but rather the locale and configuration of the browser at hand.
				// When using an input with type='number' the displayed decimal separator is selected accordingly, while the underlying value format is standardized.
				
				current.val.val(a);
			}
	
			fields.forEach(function(f)
			{
				var others = fields.filter(function(f2)
				{
					return f != f2;
				});
		
				var onChange = function()
				{
					others.forEach(function(f2)
					{
						update(f2, f);
					})
				};
		
				f.val.change(onChange);
				f.val.keyup(onChange);
				f.type.change(onChange);
				f.type.keyup(onChange);
		
				var valTD = $("<td/>");
				valTD.append(f.val);
				fieldsElement.append(valTD);
				var typeTD = $("<td/>");
				typeTD.append(f.type);
				fieldsElement.append(typeTD);
			});
		}
	
		// Overview
		{
			var fieldInitials = [ 'USD', 'EUR', 'GBP', 'CHF', 'JPY', 'CAD', 'AUD' ];
			var overviewSelector = $("#overview-selector");
			var overview = $("#overview");
			fields = [];
			
			var createOverview = function()
			{
				overview.empty();
				
				var selected = fields.filter(function(e)
				{
					return e[0].checked;
				});
				selected.forEach(function(e)
				{
					var row = $("<tr/>");
					var key = e.val();
					var rate = rates[key];
					var others = selected.filter(function(o) { return o.val() != key });
					
					var head = $("<th/>");
					head.text("1 " + key + ":");
					row.append(head);
					
					others.forEach(function(o)
					{
						var td = $("<td/>");
						var otherKey = o.val();
						var otherRate = rates[otherKey];
						var a = (1.0 / rate) * otherRate;
						// toLocaleString can also be used to display currency values with their currency symbols,
						// this is not used here because it makes the table less coherent.
						td.text(a.toLocaleString
						(
							navigator.language,
							{
								maximumFractionDigits: 4
							}
						) + " " + otherKey);
						
						row.append(td);
					})
					
					overview.append(row);
				});
			};
			
			// Create selectors
			fieldInitials.forEach(function(e)
			{
				var label = $("<label/>");
				label.text(e);
				label.css("margin-right", "10px");
				var input = $('<input type="checkbox"/>')
				input.val(e);
				input[0].checked = true;
				input[0].onchange = createOverview;
				label.append(input);
				overviewSelector.append(label);
				
				fields.push(input);
			});
			
			createOverview();
		}
	}
});
